#!/bin/sh
#########################################################################
#  This script is to be sourced to set the paths to fvs scripts and	#
#  executable files.							#
#									#
#  Log:									#
#  K. Brill	 5/98							#
#  K. Brill	01/00	Point environment to hp52			#
#  K. Brill	07/00	Changes for AIX					#
#  K. Brill	12/00	Eliminate hp52 -- use ~wd22kb			#
#  K. Brill      6/01	Set DDAPP if not defined.  Check for OS defined #
#  K. Brill	11/02	Added IRIX64					#
#  K. Brill/HPC	 3/03	Changed VSDB_DATA				#
#  K. Brill/HPC	 8/04	Point DDAPP to /export-4/hp52/ddapp		#
#  K. Brill/HPC	 6/05	Eliminate hp52; simplify; check vsdb_dev set	#
#  K. Brill/HPC	 8/05	Check for VSDB set before _dev check		#
#  K. Brill/HPC 10/05	Check for EMC workstation "tempest"		#
#  K. Brill/HPC 20061025 Change wx22kb to wx32kb			#
#  K. Brill/HPC 20070307 DDAPP=/hpc/save/ddapp; VSDB=/hpc/save/vsdb     #
#  K. Brill/HPC 20070406 Do not exit if NAWIPS not set, print warning;	#
#                        changes to simplify remote installation	#
#  K. Brill/HPC 20080208 Set GEMEXE					#
#  K. Brill/HPC 20080703 Changed VSDB_DATA to ~wd22kb HPC path		#
#  K. Brill/HPC 20110428 Set paths to RHEL5 executable files		#
#  K. Brill/HPC 20120309 Set paths for linux64 (lnx6) on tempest	#
#  K. Brill/HPC 20131120 Set paths for lnx6 workstations		#
#  K. Brill/WPC 20141203 grep $VSDB for _dev not just dev		#
#########################################################################

if [ ${OS:-null} = "null" ]; then
    cat << EOF

        WARNING ---------->>

	NAWIPS paths and environment variables must be set first.

        Only fvs DEV=TX will work.

EOF
    OS=`uname`
    export OS
fi

wrkstn=`hostname -s`

if [ ${VSDB:-null} != "null" ]; then
    echo $VSDB | grep _dev > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        VSDB=$HOME/vsdb
        export VSDB
    fi
fi

if [ $OS = AIX ]; then
    if [ -d /hpc/save/vsdb ]; then
        xVSDB=/hpc/save/vsdb
        xVSDB_DATA=/hpc/save/vsdb_data
        DDAPP=/hpc/save/ddapp
	export DDAPP
    else
        xVSDB=~wx32kb/vsdb
        xVSDB_DATA=~wx32kb/vsdb_data
	DDAPP=~wx32kb/ddapp;export DDAPP
    fi
else
    xVSDB=~wd22kb/vsdb
    xVSDB_DATA=~wd22kb/vsdbdata/vsdb_pmsl
fi
if [ ${VSDB:-null} = "null" ]; then
    VSDB=$xVSDB
    export VSDB
fi
if [ ${VSDB_DATA:-null} = "null" ]; then
    VSDB_DATA=$xVSDB_DATA
    export VSDB_DATA
fi

VSDB_TBL=$VSDB/tables
VSDB_HLP=$VSDB/help
VSDB_SCRIPTS=$VSDB/scripts
VSDB_DAY1=199001010000
VSDB_TEMP=/tmp
export VSDB_TBL VSDB_HLP VSDB_SCRIPTS VSDB_DAY1 VSDB_TEMP

# If $DDAPP is defined, the executable files may be under $DDAPP.

if [ ${DDAPP:-null} != "null" ]; then
  if [ $OS = HPUX -o -d /etc/sys_hp -o `uname` = "HP-UX" ]; then
    echo $PATH | grep exe_hp > /dev/null 2>&1
    if [ $? -ne 0 ]; then
	PATH="$PATH:$DDAPP/exe_hp"
    fi
    VSDB_LIB=$VSDB/lib/hp
  elif [ $OS = IRIX ]; then
    echo $PATH | grep exe_sg5 > /dev/null 2>&1
    if [ $? -ne 0 ]; then
	PATH="$PATH:$DDAPP/exe_sg5"
    fi
    VSDB_LIB=$VSDB/lib/sg5
  elif [ $OS = IRIX64 ]; then
    echo $PATH | grep exe_sg64 > /dev/null 2>&1
    if [ $? -ne 0 ]; then
	PATH="$PATH:$DDAPP/exe_sg64"
    fi
    VSDB_LIB=$VSDB/lib/sg64
  elif [ $OS = Linux -o $OS = LINUX -o $OS = linux64 ]; then
    if [ $wrkstn = tempest ]; then
        echo $PATH | grep exe_lnx6 > /dev/null 2>&1
        if [ $? -ne 0 ]; then
	    PATH="$PATH:$DDAPP/exe_lnx6"
        fi
        VSDB_LIB=$VSDB/lib/lnx6
    elif [ .$NA_OS = ".linux2.6.18el64" ]; then
        echo $PATH | grep exe_lnx5 > /dev/null 2>&1
        if [ $? -ne 0 ]; then
	    PATH="$PATH:$DDAPP/exe_lnx5"
        fi
        VSDB_LIB=$VSDB/lib/lnx5
    elif [ .$NA_OS = ".linux2.6.32_x86_64" ]; then
        echo $PATH | grep exe_lnx6 > /dev/null 2>&1
        if [ $? -ne 0 ]; then
	    PATH="$PATH:$DDAPP/exe_lnx6"
        fi
        VSDB_LIB=$VSDB/lib/lnx6
    else
        echo $PATH | grep exe_lnx > /dev/null 2>&1
        if [ $? -ne 0 ]; then
	    PATH="$PATH:$DDAPP/exe_lnx"
        fi
        VSDB_LIB=$VSDB/lib/lnx
    fi
  elif [ $OS = AIX ]; then
    echo $PATH | grep exe_aix > /dev/null 2>&1
    if [ $? -ne 0 ]; then
	PATH="$PATH:$DDAPP/exe_aix"
    fi
    VSDB_LIB=$VSDB/lib/aix
  else
    echo fvs is not supported on this UNIX platform.
    exit
  fi
fi

PATH="$PATH:$VSDB/scripts"
export PATH VSDB_LIB

if [ ${GEMEXE:-null} = null ]; then
    gplt_path=`type gplt | cut -d" " -f3`
    GEMEXE=`dirname $gplt_path`
    export GEMEXE
fi
