#!/bin/sh
#########################################################################
#  This /sh script allows the user to set the VSDB_DATA environmental	#
#  variable to one of several options.					#
#									#
#  This script must be sourced!!					#
#									#
#  Log:									#
#  K. Brill/EMC		 4/99  Created from set_vsdb_data		#
#  K. Brill/HPC		01/00	Added precip type path setting		#
#  K. Brill/HPC		01/00	$< -> "$<" for Linux			#
#  K. Brill/HPC		 6/00	Added PMSL and Snowfall risk paths	#
#  K. Brill/HPC		 4/01	Added HPC PMSL L1L2 path		#
#  K. Brill/HPC		11/02	Added HPC heat index path		#
#  K. Brill/HPC		 2/03	Changed paths for 1 & 2			#
#  K. Brill/HPC		 3/03	Created from set_vsdb_data2 for csh	#
#  K. Brill/HPC		 4/03	Eliminate dual paths for 1 & 2; add WWE	#
#  K. Brill/HPC		 2/04	Fix close " for option 11		#
#  K. Brill/HPC		 8/05	Add WWP verification			#
#  K. Brill/HPC		11/05	Added SLR and 6-h QPF			#
#  K. Brill/HPC		01/06	Added 24-h QPF				#
#  K. Brill/HPC         01/07   Point to EMC verification on tempest	#
#  K. Brill/HPC      20070827   Add vsdb_bpcp path as 17		#
#  K. Brill/HPC      20081106   Add 6hqpf, EMC_vsdb, and pqpf		#
#  K. Brill/HPC      20091204   Add oppqpf				#
#  K. Brill/HPC      20120123   Add selections 26--30			#
#  K. Brill/HPC      20120703   Add selection 31			#
#  K. Brill/IMSG     20160728   Change wording for option 0		#
#########################################################################

env | grep VSDB_DATA > /dev/null 2>&1
if [ $? -ne  0 ]; then
    curpath="not set"
else
    curpath=$VSDB_DATA
fi

if [ $? -eq 0 ]; then
    echo " "
    echo The current VSDB data path is $curpath
    echo " "
    echo " "
    echo "	Select option by number:"
    echo " "
    echo "	0 => Proceed without changing current path"
    echo "	1 => Set path to Grid to Obs Verification Data"
    echo "	2 => Set path to Precipitation Verification Data"
    echo "	3 => Set path to GLOBAL Verification Data"
    echo "	4 => Set path to Precip Type Verification Data"
    echo "	5 => Set path to VLCEK statistics"
    echo "	6 => Set path to HPC PMSL phase error verification"
    echo "	7 => Set path to Snowfall/Ice risk verification"
    echo "	8 => Set path to HPC PMSL L1L2 verification"
    echo "	9 => Set path to QPF location error verification"
    echo "     10 => Set path to HPC Heat Index verification"
    echo "     11 => Set path to Winter Wx Desk accumulation verification"
    echo "     12 => Set path to Excessive Rainfall (94E) verification"
    echo "     13 => Set path to WWD probabilistic frcst verification"
    echo "     14 => Set path to SLR verification"
    echo "     15 => Set path to verification of automated vs HPC 6-h QPF"
    echo "     16 => Set path to verification of automated vs HPC 24-h QPF"
    echo "     17 => Set path to verification of HPC BWX Broken Precip"
    echo "     18 => Set path to verification of HPC AK DESK PMSL"
    echo "     19 => Set path to ST_MODE verification"
    echo "     20 => Set path to grid-to-grid verification of 6-h QPF"
    echo "     21 => Set path to copied EMC model verification"
    echo "     22 => Set path to exprmntl probabilistic QPF (PQPF) verification"
    echo "     23 => Set path to grid-to-grid verif of 6-h Puerto Rico QPF"
    echo "     24 => Set path to operational probabilistic QPF (PQPF) verification"
    echo "     25 => Set path to Percentile Forecast Reliability (PFR) verification"
    echo "     26 => Set path to NDFD PQPF verification"
    echo "     27 => Set path to NDFD PFR verification"
    echo "     28 => Set path to operational 24-h PQPF verification"
    echo "     29 => Set path to operational 24-h PFR verification"
    echo "     30 => Set path to HPC QPF FCI verification"
    echo "     31 => Set path to QPE vs HPC MANUAL analysis"
    echo "     32 => Enter the path"
    echo "	"
	read iresp
	if [ $iresp = 0 ]; then
	    echo VSDB data path is $VSDB_DATA
	elif [ $iresp = 1 ]; then
	    VSDB_DATA=/export-4/tempest/wd20er/data/vsdb
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 2 ]; then
	    VSDB_DATA=/export-4/tempest/wd22yl/vsdb_prcp24
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 3 ]; then
	    VSDB_DATA=/export-6/emc2/wdstat
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 4 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_ptype
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 5 ]; then
	    VSDB_DATA=$VSDB_DISK/vlcek_vsdb
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 6 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_pmsl
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 7 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_wwx
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 8 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_sa-pmsl
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 9 ]; then
	    VSDB_DATA=$VSDB_DISK/dberz
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 10 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_hi
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 11 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_ww
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 12 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_exrf
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 13 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_wwp
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 14 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_sacc
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 15 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_qpf
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 16 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_qpf24
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 17 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_bpcp
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 18 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_ak-pmsl
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 19 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_mode
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 20 ]; then
	    VSDB_DATA=$VSDB_DISK/6hqpf
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 21 ]; then
	    VSDB_DATA=$VSDB_DISK/EMC_vsdb
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 22 ]; then
	    VSDB_DATA=$VSDB_DISK/pqpf
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 23 ]; then
	    VSDB_DATA=$VSDB_DISK/prqpf
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 24 ]; then
	    VSDB_DATA=$VSDB_DISK/oppqpf
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 25 ]; then
	    VSDB_DATA=$VSDB_DISK/oppfr
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 26 ]; then
	    VSDB_DATA=$VSDB_DISK/ndfdpqpf
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 27 ]; then
	    VSDB_DATA=$VSDB_DISK/ndfdpfr
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 28 ]; then
	    VSDB_DATA=$VSDB_DISK/oppqpf24
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 29 ]; then
	    VSDB_DATA=$VSDB_DISK/oppfr24
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 30 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_qpffci
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 31 ]; then
	    VSDB_DATA=$VSDB_DISK/vsdb_qpe24
	    echo VSDB data path is now $VSDB_DATA
	elif [ $iresp = 32 ]; then
	    echo " "
	    echo "	Enter the data path below:"
	    echo " "
	    read vsdbpath
	    VSDB_DATA=$vsdbpath
	    echo VSDB data path is now $VSDB_DATA
	else
	    echo "INVALID SELECTION"
	fi
fi
export VSDB_DATA

vsdb_data=`echo $VSDB_DATA | cut -d":" -f1`

if [ ! -d $vsdb_data ]; then
    echo " "
    echo $vsdb_data does not exist.
fi
